"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerReportDeadBodyEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player reports a dead body of a player, telling the host to
 * begin a meeting.
 *
 * This event is only emitted if the client is the host, see
 * {@link PlayerStartMeetingEvent} to listen for a meeting being started regardless
 * of whether the client is the host or not.
 */
class PlayerReportDeadBodyEvent extends events_1.CancelableEvent {
    constructor(room, player, message, 
    /**
     * The body that the player reported, or "emergency" if the player called
     * an emergency meeting.
     */
    body) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.body = body;
        this.eventName = "player.reportbody";
        this._alteredBody = body;
    }
    /**
     * The altered body that will be reported instead, if changed.
     */
    get alteredBody() {
        return this._alteredBody;
    }
    /**
     * Set the report to be calling an emergency meeting.
     */
    setEmergency() {
        this.setBody("emergency");
    }
    /**
     * Change the body that will be reported.
     * @param body The body for the player to report.
     */
    setBody(body) {
        this._alteredBody = body;
    }
}
exports.PlayerReportDeadBodyEvent = PlayerReportDeadBodyEvent;
PlayerReportDeadBodyEvent.eventName = "player.reportbody";
//# sourceMappingURL=ReportDeadBody.js.map