"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetPetEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player pet updated.
 */
class PlayerSetPetEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The pet that hte player had before.
     */
    oldPet, 
    /**
     * The new pet that the player has.
     */
    newPet) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldPet = oldPet;
        this.newPet = newPet;
        this.eventName = "player.setpet";
        this._alteredPet = newPet;
    }
    /**
     * The altered pet that the player will have set instead, if changed.
     */
    get alteredPet() {
        return this._alteredPet;
    }
    /**
     * Revert the player's pet back to their old pet.
     */
    revert() {
        this.setPet(this.oldPet);
    }
    /**
     * Change the pet that the player had set.
     * @param pet The pet to set.
     */
    setPet(pet) {
        this._alteredPet = pet;
    }
}
exports.PlayerSetPetEvent = PlayerSetPetEvent;
PlayerSetPetEvent.eventName = "player.setpet";
//# sourceMappingURL=SetPet.js.map