"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoomSelectImpostorsEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when the room picks which impostors will be selected, after the game
 * is started. Can be canceled to avoid choosing and setting impostors altogether.
 *
 * Mainly emitted in order to allow overriding of the default impostor
 * selection in SkeldJS.
 */
class RoomSelectImpostorsEvent extends events_1.CancelableEvent {
    constructor(room, 
    /**
     * The players that were chosen to be impostors.
     */
    impostors) {
        super();
        this.room = room;
        this.impostors = impostors;
        this.eventName = "room.selectimpostors";
        this._alteredImpostors = impostors;
    }
    /**
     * The altered impostor list that will be used instead, if changed.
     */
    get alteredImpostors() {
        return this._alteredImpostors;
    }
    /**
     * Change the players that were selected.
     * @param impostors The players to select.
     */
    setImpostors(impostors) {
        this._alteredImpostors = impostors;
    }
}
exports.RoomSelectImpostorsEvent = RoomSelectImpostorsEvent;
RoomSelectImpostorsEvent.eventName = "room.selectimpostors";
//# sourceMappingURL=SelectImpostors.js.map